@@ -14,40 +14,12 @@
 
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** SPDX-FileCopyrightText: 2016 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtSql module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
+** SPDX-License-Identifier: LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KFQF-Accepted-GPL OR LicenseRef-Qt-Commercial
 **
 ****************************************************************************/
 
@@ -65,14 +37,9 @@
 #include <qstringlist.h>
 #include <qvector.h>
 #include <qdebug.h>
-#if QT_CONFIG(regularexpression)
-#include <qcache.h>
-#include <qregularexpression.h>
-#endif
 #if QT_CONFIG(timezone)
 #include <QTimeZone>
 #endif
-#include <QScopedValueRollback>
 
 #if defined Q_OS_WIN
 # include <qt_windows.h>
@@ -107,17 +74,17 @@ static QVariant::Type qGetColumnType(const QString &tpName)
     const QString typeName = tpName.toLower();
 
     if (typeName == QLatin1String("integer")
-        || typeName == QLatin1String("int"))
+            || typeName == QLatin1String("int"))
         return QVariant::Int;
     if (typeName == QLatin1String("double")
-        || typeName == QLatin1String("float")
-        || typeName == QLatin1String("real")
-        || typeName.startsWith(QLatin1String("numeric")))
+            || typeName == QLatin1String("float")
+            || typeName == QLatin1String("real")
+            || typeName.startsWith(QLatin1String("numeric")))
         return QVariant::Double;
     if (typeName == QLatin1String("blob"))
         return QVariant::ByteArray;
     if (typeName == QLatin1String("boolean")
-        || typeName == QLatin1String("bool"))
+            || typeName == QLatin1String("bool"))
         return QVariant::Bool;
     return QVariant::String;
 }
@@ -140,20 +107,19 @@ class QSQLiteResult : public QSqlCachedResult
 public:
     explicit QSQLiteResult(const QSQLiteDriver* db);
     ~QSQLiteResult();
-    QVariant handle() const override;
+    QVariant handle() const Q_DECL_OVERRIDE;
 
 protected:
-    bool gotoNext(QSqlCachedResult::ValueCache& row, int idx) override;
-    bool reset(const QString &query) override;
-    bool prepare(const QString &query) override;
-    bool execBatch(bool arrayBind) override;
-    bool exec() override;
-    int size() override;
-    int numRowsAffected() override;
-    QVariant lastInsertId() const override;
-    QSqlRecord record() const override;
-    void detachFromResultSet() override;
-    void virtual_hook(int id, void *data) override;
+    bool gotoNext(QSqlCachedResult::ValueCache& row, int idx) Q_DECL_OVERRIDE;
+    bool reset(const QString &query) Q_DECL_OVERRIDE;
+    bool prepare(const QString &query) Q_DECL_OVERRIDE;
+    bool exec() Q_DECL_OVERRIDE;
+    int size() Q_DECL_OVERRIDE;
+    int numRowsAffected() Q_DECL_OVERRIDE;
+    QVariant lastInsertId() const Q_DECL_OVERRIDE;
+    QSqlRecord record() const Q_DECL_OVERRIDE;
+    void detachFromResultSet() Q_DECL_OVERRIDE;
+    void virtual_hook(int id, void *data) Q_DECL_OVERRIDE;
 };
 
 class QSQLiteDriverPrivate : public QSqlDriverPrivate
@@ -161,7 +127,9 @@ class QSQLiteDriverPrivate : public QSqlDriverPrivate
     Q_DECLARE_PUBLIC(QSQLiteDriver)
 
 public:
-    inline QSQLiteDriverPrivate() : QSqlDriverPrivate(), access(0) { dbmsType = QSqlDriver::SQLite; }
+    inline QSQLiteDriverPrivate() : QSqlDriverPrivate(), access(0) {
+        dbmsType = QSqlDriver::SQLite;
+    }
     sqlite3 *access;
     QList <QSQLiteResult *> results;
     QStringList notificationid;
@@ -229,16 +197,12 @@ void QSQLiteResultPrivate::initColumns(bool emptyResultset)
 
     for (int i = 0; i < nCols; ++i) {
         QString colName = QString(reinterpret_cast<const QChar *>(
-                    sqlite3_column_name16(stmt, i))
-                    ).remove(QLatin1Char('"'));
-#ifdef ENABLE_COLUMN_METADATA
-        const QString tableName = QString(reinterpret_cast<const QChar *>(
-                            sqlite3_column_table_name16(stmt, i))
-                            ).remove(QLatin1Char('"'));
-#endif
+                                      sqlite3_column_name16(stmt, i))
+                                 ).remove(QLatin1Char('"'));
+
         // must use typeName for resolving the type to match QSqliteDriver::record
         QString typeName = QString(reinterpret_cast<const QChar *>(
-                    sqlite3_column_decltype16(stmt, i)));
+                                       sqlite3_column_decltype16(stmt, i)));
         // sqlite3_column_type is documented to have undefined behavior if the result set is empty
         int stp = emptyResultset ? -1 : sqlite3_column_type(stmt, i);
 
@@ -267,11 +231,8 @@ void QSQLiteResultPrivate::initColumns(bool emptyResultset)
                 break;
             }
         }
-#ifdef ENABLE_COLUMN_METADATA
-        QSqlField fld(colName, fieldType, tableName);
-#else
+
         QSqlField fld(colName, fieldType);
-#endif
         fld.setSqlType(stp);
         rInf.append(fld);
     }
@@ -287,7 +248,7 @@ bool QSQLiteResultPrivate::fetchNext(QSqlCachedResult::ValueCache &values, int i
         // already fetched
         Q_ASSERT(!initialFetch);
         skipRow = false;
-        for(int i=0;i<firstRow.count();i++)
+        for(int i=0; i<firstRow.count(); i++)
             values[i]=firstRow[i];
         return skippedStatus;
     }
@@ -318,25 +279,25 @@ bool QSQLiteResultPrivate::fetchNext(QSqlCachedResult::ValueCache &values, int i
             switch (sqlite3_column_type(stmt, i)) {
             case SQLITE_BLOB:
                 values[i + idx] = QByteArray(static_cast<const char *>(
-                            sqlite3_column_blob(stmt, i)),
-                            sqlite3_column_bytes(stmt, i));
+                                                 sqlite3_column_blob(stmt, i)),
+                                             sqlite3_column_bytes(stmt, i));
                 break;
             case SQLITE_INTEGER:
                 values[i + idx] = sqlite3_column_int64(stmt, i);
                 break;
             case SQLITE_FLOAT:
                 switch(q->numericalPrecisionPolicy()) {
-                    case QSql::LowPrecisionInt32:
-                        values[i + idx] = sqlite3_column_int(stmt, i);
-                        break;
-                    case QSql::LowPrecisionInt64:
-                        values[i + idx] = sqlite3_column_int64(stmt, i);
-                        break;
-                    case QSql::LowPrecisionDouble:
-                    case QSql::HighPrecision:
-                    default:
-                        values[i + idx] = sqlite3_column_double(stmt, i);
-                        break;
+                case QSql::LowPrecisionInt32:
+                    values[i + idx] = sqlite3_column_int(stmt, i);
+                    break;
+                case QSql::LowPrecisionInt64:
+                    values[i + idx] = sqlite3_column_int64(stmt, i);
+                    break;
+                case QSql::LowPrecisionDouble:
+                case QSql::HighPrecision:
+                default:
+                    values[i + idx] = sqlite3_column_double(stmt, i);
+                    break;
                 };
                 break;
             case SQLITE_NULL:
@@ -344,8 +305,8 @@ bool QSQLiteResultPrivate::fetchNext(QSqlCachedResult::ValueCache &values, int i
                 break;
             default:
                 values[i + idx] = QString(reinterpret_cast<const QChar *>(
-                            sqlite3_column_text16(stmt, i)),
-                            sqlite3_column_bytes16(stmt, i) / sizeof(QChar));
+                                              sqlite3_column_text16(stmt, i)),
+                                          sqlite3_column_bytes16(stmt, i) / sizeof(QChar));
                 break;
             }
         }
@@ -363,7 +324,7 @@ bool QSQLiteResultPrivate::fetchNext(QSqlCachedResult::ValueCache &values, int i
         // to get the specific error message.
         res = sqlite3_reset(stmt);
         q->setLastError(qMakeError(drv_d_func()->access, QCoreApplication::translate("QSQLiteResult",
-                        "Unable to fetch row"), QSqlError::ConnectionError, res));
+                                   "Unable to fetch row"), QSqlError::ConnectionError, res));
         q->setAt(QSql::AfterLastRow);
         return false;
     case SQLITE_MISUSE:
@@ -371,7 +332,7 @@ bool QSQLiteResultPrivate::fetchNext(QSqlCachedResult::ValueCache &values, int i
     default:
         // something wrong, don't get col info, but still return false
         q->setLastError(qMakeError(drv_d_func()->access, QCoreApplication::translate("QSQLiteResult",
-                        "Unable to fetch row"), QSqlError::ConnectionError, res));
+                                   "Unable to fetch row"), QSqlError::ConnectionError, res));
         sqlite3_reset(stmt);
         q->setAt(QSql::AfterLastRow);
         return false;
@@ -428,12 +389,12 @@ bool QSQLiteResult::prepare(const QString &query)
 
     if (res != SQLITE_OK) {
         setLastError(qMakeError(d->drv_d_func()->access, QCoreApplication::translate("QSQLiteResult",
-                     "Unable to execute statement"), QSqlError::StatementError, res));
+                                "Unable to execute statement"), QSqlError::StatementError, res));
         d->finalize();
         return false;
     } else if (pzTail && !QString(reinterpret_cast<const QChar *>(pzTail)).trimmed().isEmpty()) {
         setLastError(qMakeError(d->drv_d_func()->access, QCoreApplication::translate("QSQLiteResult",
-            "Unable to execute multiple statements at a time"), QSqlError::StatementError, SQLITE_MISUSE));
+                                "Unable to execute multiple statements at a time"), QSqlError::StatementError, SQLITE_MISUSE));
         d->finalize();
         return false;
     }
@@ -468,33 +429,10 @@ static QString timespecToString(const QDateTime &dateTime)
     }
 }
 
-bool QSQLiteResult::execBatch(bool arrayBind)
-{
-    Q_UNUSED(arrayBind);
-    Q_D(QSqlResult);
-    QScopedValueRollback<QVector<QVariant>> valuesScope(d->values);
-    QVector<QVariant> values = d->values;
-    if (values.count() == 0)
-        return false;
-
-    for (int i = 0; i < values.at(0).toList().count(); ++i) {
-        d->values.clear();
-        QScopedValueRollback<QHash<QString, QVector<int>>> indexesScope(d->indexes);
-        QHash<QString, QVector<int>>::const_iterator it = d->indexes.constBegin();
-        while (it != d->indexes.constEnd()) {
-            bindValue(it.key(), values.at(it.value().first()).toList().at(i), QSql::In);
-            ++it;
-        }
-        if (!exec())
-            return false;
-    }
-    return true;
-}
-
 bool QSQLiteResult::exec()
 {
     Q_D(QSQLiteResult);
-    QVector<QVariant> values = boundValues();
+    const QVector<QVariant> values = boundValues();
 
     d->skippedStatus = false;
     d->skipRow = false;
@@ -505,49 +443,12 @@ bool QSQLiteResult::exec()
     int res = sqlite3_reset(d->stmt);
     if (res != SQLITE_OK) {
         setLastError(qMakeError(d->drv_d_func()->access, QCoreApplication::translate("QSQLiteResult",
-                     "Unable to reset statement"), QSqlError::StatementError, res));
+                                "Unable to reset statement"), QSqlError::StatementError, res));
         d->finalize();
         return false;
     }
-
     int paramCount = sqlite3_bind_parameter_count(d->stmt);
-    bool paramCountIsValid = paramCount == values.count();
-
-#if (SQLITE_VERSION_NUMBER >= 3003011)
-    // In the case of the reuse of a named placeholder
-    // We need to check explicitly that paramCount is greater than or equal to 1, as sqlite
-    // can end up in a case where for virtual tables it returns 0 even though it
-    // has parameters
-    if (paramCount >= 1 && paramCount < values.count()) {
-        const auto countIndexes = [](int counter, const QVector<int> &indexList) {
-                                      return counter + indexList.length();
-                                  };
-
-        const int bindParamCount = std::accumulate(d->indexes.cbegin(),
-                                                   d->indexes.cend(),
-                                                   0,
-                                                   countIndexes);
-
-        paramCountIsValid = bindParamCount == values.count();
-        // When using named placeholders, it will reuse the index for duplicated
-        // placeholders. So we need to ensure the QVector has only one instance of
-        // each value as SQLite will do the rest for us.
-        QVector<QVariant> prunedValues;
-        QVector<int> handledIndexes;
-        for (int i = 0, currentIndex = 0; i < values.size(); ++i) {
-            if (handledIndexes.contains(i))
-                continue;
-            const auto placeHolder = QString::fromUtf8(sqlite3_bind_parameter_name(d->stmt, currentIndex + 1));
-            const auto &indexes = d->indexes.value(placeHolder);
-            handledIndexes << indexes;
-            prunedValues << values.at(indexes.first());
-            ++currentIndex;
-        }
-        values = prunedValues;
-    }
-#endif
-
-    if (paramCountIsValid) {
+    if (paramCount == values.count()) {
         for (int i = 0; i < paramCount; ++i) {
             res = SQLITE_OK;
             const QVariant value = values.at(i);
@@ -560,7 +461,8 @@ bool QSQLiteResult::exec()
                     const QByteArray *ba = static_cast<const QByteArray*>(value.constData());
                     res = sqlite3_bind_blob(d->stmt, i + 1, ba->constData(),
                                             ba->size(), SQLITE_STATIC);
-                    break; }
+                    break;
+                }
                 case QVariant::Int:
                 case QVariant::Bool:
                     res = sqlite3_bind_int(d->stmt, i + 1, value.toInt());
@@ -574,14 +476,14 @@ bool QSQLiteResult::exec()
                     break;
                 case QVariant::DateTime: {
                     const QDateTime dateTime = value.toDateTime();
-                    const QString str = dateTime.toString(QLatin1String("yyyy-MM-ddThh:mm:ss.zzz") + timespecToString(dateTime));
+                    const QString str = dateTime.toString(QStringLiteral("yyyy-MM-ddThh:mm:ss.zzz") + timespecToString(dateTime));
                     res = sqlite3_bind_text16(d->stmt, i + 1, str.utf16(),
                                               str.size() * sizeof(ushort), SQLITE_TRANSIENT);
                     break;
                 }
                 case QVariant::Time: {
                     const QTime time = value.toTime();
-                    const QString str = time.toString(QStringViewLiteral("hh:mm:ss.zzz"));
+                    const QString str = time.toString(QStringLiteral("hh:mm:ss.zzz"));
                     res = sqlite3_bind_text16(d->stmt, i + 1, str.utf16(),
                                               str.size() * sizeof(ushort), SQLITE_TRANSIENT);
                     break;
@@ -591,25 +493,27 @@ bool QSQLiteResult::exec()
                     const QString *str = static_cast<const QString*>(value.constData());
                     res = sqlite3_bind_text16(d->stmt, i + 1, str->utf16(),
                                               (str->size()) * sizeof(QChar), SQLITE_STATIC);
-                    break; }
+                    break;
+                }
                 default: {
                     QString str = value.toString();
                     // SQLITE_TRANSIENT makes sure that sqlite buffers the data
                     res = sqlite3_bind_text16(d->stmt, i + 1, str.utf16(),
                                               (str.size()) * sizeof(QChar), SQLITE_TRANSIENT);
-                    break; }
+                    break;
+                }
                 }
             }
             if (res != SQLITE_OK) {
                 setLastError(qMakeError(d->drv_d_func()->access, QCoreApplication::translate("QSQLiteResult",
-                             "Unable to bind parameters"), QSqlError::StatementError, res));
+                                        "Unable to bind parameters"), QSqlError::StatementError, res));
                 d->finalize();
                 return false;
             }
         }
     } else {
         setLastError(QSqlError(QCoreApplication::translate("QSQLiteResult",
-                        "Parameter count mismatch"), QString(), QSqlError::StatementError));
+                               "Parameter count mismatch"), QString(), QSqlError::StatementError));
         return false;
     }
     d->skippedStatus = d->fetchNext(d->firstRow, 0, true);
@@ -674,40 +578,6 @@ QVariant QSQLiteResult::handle() const
 
 /////////////////////////////////////////////////////////
 
-#if QT_CONFIG(regularexpression)
-static void _q_regexp(sqlite3_context* context, int argc, sqlite3_value** argv)
-{
-    if (Q_UNLIKELY(argc != 2)) {
-        sqlite3_result_int(context, 0);
-        return;
-    }
-
-    const QString pattern = QString::fromUtf8(
-        reinterpret_cast<const char*>(sqlite3_value_text(argv[0])));
-    const QString subject = QString::fromUtf8(
-        reinterpret_cast<const char*>(sqlite3_value_text(argv[1])));
-
-    auto cache = static_cast<QCache<QString, QRegularExpression>*>(sqlite3_user_data(context));
-    auto regexp = cache->object(pattern);
-    const bool wasCached = regexp;
-
-    if (!wasCached)
-        regexp = new QRegularExpression(pattern, QRegularExpression::DontCaptureOption | QRegularExpression::OptimizeOnFirstUsageOption);
-
-    const bool found = subject.contains(*regexp);
-
-    if (!wasCached)
-        cache->insert(pattern, regexp);
-
-    sqlite3_result_int(context, int(found));
-}
-
-static void _q_regexp_cleanup(void *cache)
-{
-    delete static_cast<QCache<QString, QRegularExpression>*>(cache);
-}
-#endif
-
 QSQLiteDriver::QSQLiteDriver(QObject * parent)
     : QSqlDriver(*new QSQLiteDriverPrivate, parent)
 {
@@ -743,17 +613,11 @@ bool QSQLiteDriver::hasFeature(DriverFeature f) const
     case EventNotifications:
         return true;
     case QuerySize:
+    case NamedPlaceholders:
     case BatchOperations:
     case MultipleResultSets:
     case CancelQuery:
         return false;
-    case NamedPlaceholders:
-#if (SQLITE_VERSION_NUMBER < 3003011)
-        return false;
-#else
-        return true;
-#endif
-
     }
     return false;
 }
@@ -773,11 +637,6 @@ bool QSQLiteDriver::open(const QString & db, const QString &, const QString &, c
     bool sharedCache = false;
     bool openReadOnlyOption = false;
     bool openUriOption = false;
-#if QT_CONFIG(regularexpression)
-    static const QLatin1String regexpConnectOption = QLatin1String("QSQLITE_ENABLE_REGEXP");
-    bool defineRegexp = false;
-    int regexpCacheSize = 25;
-#endif
 
     const auto opts = conOpts.splitRef(QLatin1Char(';'));
     for (auto option : opts) {
@@ -797,42 +656,18 @@ bool QSQLiteDriver::open(const QString & db, const QString &, const QString &, c
         } else if (option == QLatin1String("QSQLITE_ENABLE_SHARED_CACHE")) {
             sharedCache = true;
         }
-#if QT_CONFIG(regularexpression)
-        else if (option.startsWith(regexpConnectOption)) {
-            option = option.mid(regexpConnectOption.size()).trimmed();
-            if (option.isEmpty()) {
-                defineRegexp = true;
-            } else if (option.startsWith(QLatin1Char('='))) {
-                bool ok = false;
-                const int cacheSize = option.mid(1).trimmed().toInt(&ok);
-                if (ok) {
-                    defineRegexp = true;
-                    if (cacheSize > 0)
-                        regexpCacheSize = cacheSize;
-                }
-            }
-        }
-#endif
     }
 
     int openMode = (openReadOnlyOption ? SQLITE_OPEN_READONLY : (SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE));
-    openMode |= (sharedCache ? SQLITE_OPEN_SHAREDCACHE : SQLITE_OPEN_PRIVATECACHE);
     if (openUriOption)
         openMode |= SQLITE_OPEN_URI;
 
-    openMode |= SQLITE_OPEN_NOMUTEX;
+    sqlite3_enable_shared_cache(sharedCache);
 
     if (sqlite3_open_v2(db.toUtf8().constData(), &d->access, openMode, NULL) == SQLITE_OK) {
         sqlite3_busy_timeout(d->access, timeOut);
         setOpen(true);
         setOpenError(false);
-#if QT_CONFIG(regularexpression)
-        if (defineRegexp) {
-            auto cache = new QCache<QString, QRegularExpression>(regexpCacheSize);
-            sqlite3_create_function_v2(d->access, "regexp", 2, SQLITE_UTF8, cache, &_q_regexp, NULL,
-                                       NULL, &_q_regexp_cleanup);
-        }
-#endif
         return true;
     } else {
         if (d->access) {
@@ -841,7 +676,7 @@ bool QSQLiteDriver::open(const QString & db, const QString &, const QString &, c
         }
 
         setLastError(qMakeError(d->access, tr("Error opening database"),
-                     QSqlError::ConnectionError));
+                                QSqlError::ConnectionError));
         setOpenError(true);
         return false;
     }
@@ -967,11 +802,7 @@ static QSqlIndex qGetTableInfo(QSqlQuery &q, const QString &tableName, bool only
         if (onlyPIndex && !isPk)
             continue;
         QString typeName = q.value(2).toString().toLower();
-#ifdef ENABLE_COLUMN_METADATA
-        QSqlField fld(q.value(1).toString(), qGetColumnType(typeName), tableName);
-#else
         QSqlField fld(q.value(1).toString(), qGetColumnType(typeName));
-#endif
         if (isPk && (typeName == QLatin1String("integer")))
             // INTEGER PRIMARY KEY fields are auto-generated in sqlite
             // INT PRIMARY KEY is not the same as INTEGER PRIMARY KEY!
