@@ -1,19 +1,8 @@
-/***************************************************************************
-                             kmymoneywizard.h
-                             -------------------
-    copyright            : (C) 2006 by Thomas Baumagrt
-    email                : ipwizard@users.sourceforge.net
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Thomas Baumagrt <ipwizard@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KMYMONEYWIZARD_H
 #define KMYMONEYWIZARD_H
@@ -136,45 +125,45 @@ template <class T> class QList;
 class KMyMoneyWizardPrivate;
 class KMyMoneyWizard : public QDialog
 {
-  friend class KMyMoneyWizardPage;
+    friend class KMyMoneyWizardPage;
 
-  Q_OBJECT
-  Q_DISABLE_COPY(KMyMoneyWizard)
+    Q_OBJECT
+    Q_DISABLE_COPY(KMyMoneyWizard)
 
 public:
-  /**
-    * Modify the title of the wizard to be @p txt.
-    *
-    * @param txt The text that should be used as title
-    */
-  void setTitle(const QString& txt);
+    /**
+      * Modify the title of the wizard to be @p txt.
+      *
+      * @param txt The text that should be used as title
+      */
+    void setTitle(const QString& txt);
 
-  /**
-    * Add step @p text to the wizard
-    *
-    * @param text Text to be shown for this step
-    */
-  void addStep(const QString& text);
+    /**
+      * Add step @p text to the wizard
+      *
+      * @param text Text to be shown for this step
+      */
+    void addStep(const QString& text);
 
-  QList<KMyMoneyWizardPage*> historyPages() const;
+    QList<KMyMoneyWizardPage*> historyPages() const;
 
-  /**
-    * This method repeats selection of the current step in the
-    * step frame.
-    * This is used to allow changes made to showing and hiding
-    * pages to immediately to be reflected in the step frame
-    */
-  void reselectStep();
+    /**
+      * This method repeats selection of the current step in the
+      * step frame.
+      * This is used to allow changes made to showing and hiding
+      * pages to immediately to be reflected in the step frame
+      */
+    void reselectStep();
 
-  /**
-   * Setup a global help context for the wizard. It will be used whenever
-   * there is no specific help context available for the current page.
-   *
-   * @sa KMyMoneyWizardPage::helpContext()
-   */
-  void setHelpContext(const QString& ctx);
+    /**
+     * Setup a global help context for the wizard. It will be used whenever
+     * there is no specific help context available for the current page.
+     *
+     * @sa KMyMoneyWizardPage::helpContext()
+     */
+    void setHelpContext(const QString& ctx);
 
-  virtual ~KMyMoneyWizard();
+    virtual ~KMyMoneyWizard();
 
 Q_SIGNALS:
 //  /**
@@ -196,24 +185,24 @@ Q_SIGNALS:
 //  void createCategory(const QString& txt, QString& id);
 
 protected:
-  KMyMoneyWizardPrivate * const d_ptr;
-  KMyMoneyWizard(KMyMoneyWizardPrivate &dd, QWidget* parent = nullptr, bool modal = false, Qt::WindowFlags f = 0);
-  /**
-    * Constructor (kept protected, so that one cannot create such an object directly)
-    */
-  explicit KMyMoneyWizard(QWidget* parent = nullptr, bool modal = false, Qt::WindowFlags f = 0);
+    KMyMoneyWizardPrivate * const d_ptr;
+    KMyMoneyWizard(KMyMoneyWizardPrivate &dd, QWidget* parent = nullptr, bool modal = false, Qt::WindowFlags f = 0);
+    /**
+      * Constructor (kept protected, so that one cannot create such an object directly)
+      */
+    explicit KMyMoneyWizard(QWidget* parent = nullptr, bool modal = false, Qt::WindowFlags f = 0);
 
 protected Q_SLOTS:
-  void accept() override;
-  void completeStateChanged();
+    void accept() override;
+    void completeStateChanged();
 
 private Q_SLOTS:
-  void backButtonClicked();
-  void nextButtonClicked();
-  void helpButtonClicked();
+    void backButtonClicked();
+    void nextButtonClicked();
+    void helpButtonClicked();
 
 private:
-  Q_DECLARE_PRIVATE(KMyMoneyWizard)
+    Q_DECLARE_PRIVATE(KMyMoneyWizard)
 };
 
 #endif
