@@ -1,20 +1,8 @@
-/***************************************************************************
-                             kloandetailspage.cpp
-                             -------------------
-    begin                : Tue Sep 25 2006
-    copyright            : (C) 2007 Thomas Baumgart
-    email                : Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Thomas Baumgart <Thomas Baumgart <ipwizard@users.sourceforge.net>>
+    SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kloandetailspage.h"
 #include "kloandetailspage_p.h"
@@ -58,10 +46,10 @@ using namespace eMyMoney;
 
 namespace NewAccountWizard
 {
-  LoanDetailsPage::LoanDetailsPage(Wizard* wizard) :
+LoanDetailsPage::LoanDetailsPage(Wizard* wizard) :
     QWidget(wizard),
     WizardPage<Wizard>(*new LoanDetailsPagePrivate(wizard), StepPayments, this, wizard)
-  {
+{
     Q_D(LoanDetailsPage);
     d->m_needCalculate = true;
     d->ui->setupUi(this);
@@ -85,14 +73,14 @@ namespace NewAccountWizard
     d->ui->m_balloonAmount->setAllowEmpty();
 
     connect(d->ui->m_calculateButton, &QAbstractButton::clicked, this, &LoanDetailsPage::slotCalculate);
-  }
+}
 
-  LoanDetailsPage::~LoanDetailsPage()
-  {
-  }
+LoanDetailsPage::~LoanDetailsPage()
+{
+}
 
-  void LoanDetailsPage::enterPage()
-  {
+void LoanDetailsPage::enterPage()
+{
     Q_D(LoanDetailsPage);
     // we need to remove a bunch of entries of the payment frequencies
     d->ui->m_termUnit->clear();
@@ -102,35 +90,35 @@ namespace NewAccountWizard
         d->m_mandatoryGroup->add(d->ui->m_loanAmount);
         if (d->ui->m_loanAmount->text().length() == 0) {
             d->ui->m_loanAmount->setValue(d->m_wizard->openingBalance().abs());
-          }
-      }
+        }
+    }
 
     switch (d->m_wizard->d_func()->m_generalLoanInfoPage->d_func()->ui->m_paymentFrequency->currentItem()) {
-      default:
+    default:
         d->ui->m_termUnit->insertItem(i18n("Payments"), (int)Schedule::Occurrence::Once);
         d->ui->m_termUnit->setCurrentItem((int)Schedule::Occurrence::Once);
         break;
-      case Schedule::Occurrence::Monthly:
+    case Schedule::Occurrence::Monthly:
         d->ui->m_termUnit->insertItem(i18n("Months"), (int)Schedule::Occurrence::Monthly);
         d->ui->m_termUnit->insertItem(i18n("Years"), (int)Schedule::Occurrence::Yearly);
         d->ui->m_termUnit->setCurrentItem((int)Schedule::Occurrence::Monthly);
         break;
-      case Schedule::Occurrence::Yearly:
+    case Schedule::Occurrence::Yearly:
         d->ui->m_termUnit->insertItem(i18n("Years"), (int)Schedule::Occurrence::Yearly);
         d->ui->m_termUnit->setCurrentItem((int)Schedule::Occurrence::Yearly);
         break;
-      }
-  }
+    }
+}
 
-  void LoanDetailsPage::slotValuesChanged()
-  {
+void LoanDetailsPage::slotValuesChanged()
+{
     Q_D(LoanDetailsPage);
     d->m_needCalculate = true;
     d->m_wizard->completeStateChanged();
-  }
+}
 
-  void LoanDetailsPage::slotCalculate()
-  {
+void LoanDetailsPage::slotCalculate()
+{
     Q_D(LoanDetailsPage);
     MyMoneyFinancialCalculator calc;
     MyMoneyMoney val;
@@ -148,7 +136,7 @@ namespace NewAccountWizard
     CF = d->m_wizard->d_func()->m_generalLoanInfoPage->d_func()->ui->m_compoundFrequency->eventsPerYear();
 
     if (PF == 0 || CF == 0)
-      return;
+        return;
 
     calc.setPF(PF);
     calc.setCF(CF);
@@ -157,140 +145,140 @@ namespace NewAccountWizard
     if (!d->ui->m_loanAmount->text().isEmpty()) {
         val = d->ui->m_loanAmount->value().abs();
         if (moneyBorrowed)
-          val = -val;
+            val = -val;
         calc.setPv(val.toDouble());
-      }
+    }
 
     if (!d->ui->m_interestRate->text().isEmpty()) {
         val = d->ui->m_interestRate->value().abs();
         calc.setIr(val.toDouble());
-      }
+    }
 
     if (!d->ui->m_paymentAmount->text().isEmpty()) {
         val = d->ui->m_paymentAmount->value().abs();
         if (moneyLend)
-          val = -val;
+            val = -val;
         calc.setPmt(val.toDouble());
-      }
+    }
 
     if (!d->ui->m_balloonAmount->text().isEmpty()) {
         val = d->ui->m_balloonAmount->value().abs();
         if (moneyLend)
-          val = -val;
+            val = -val;
         calc.setFv(val.toDouble());
-      }
+    }
 
     if (d->ui->m_termAmount->value() != 0) {
         calc.setNpp(term());
-      }
+    }
 
     // setup of parameters is done, now do the calculation
     try {
-      if (d->ui->m_loanAmount->text().isEmpty()) {
-          // calculate the amount of the loan out of the other information
-          val = MyMoneyMoney(calc.presentValue());
-          d->ui->m_loanAmount->setValue(val);
-          result = i18n("KMyMoney has calculated the amount of the loan as %1.", d->ui->m_loanAmount->text());
+        if (d->ui->m_loanAmount->text().isEmpty()) {
+            // calculate the amount of the loan out of the other information
+            val = MyMoneyMoney(calc.presentValue());
+            d->ui->m_loanAmount->setValue(val);
+            result = i18n("KMyMoney has calculated the amount of the loan as %1.", d->ui->m_loanAmount->text());
 
         } else if (d->ui->m_interestRate->text().isEmpty()) {
-          // calculate the interest rate out of the other information
-          val = MyMoneyMoney(calc.interestRate());
+            // calculate the interest rate out of the other information
+            val = MyMoneyMoney(calc.interestRate());
 
-          d->ui->m_interestRate->setValue(val);
-          result = i18n("KMyMoney has calculated the interest rate to %1%.", d->ui->m_interestRate->text());
+            d->ui->m_interestRate->setValue(val);
+            result = i18n("KMyMoney has calculated the interest rate to %1%.", d->ui->m_interestRate->text());
 
         } else if (d->ui->m_paymentAmount->text().isEmpty()) {
-          // calculate the periodical amount of the payment out of the other information
-          val = MyMoneyMoney(calc.payment());
-          d->ui->m_paymentAmount->setValue(val.abs());
-          // reset payment as it might have changed due to rounding
-          val = d->ui->m_paymentAmount->value().abs();
-          if (moneyLend)
-            val = -val;
-          calc.setPmt(val.toDouble());
+            // calculate the periodical amount of the payment out of the other information
+            val = MyMoneyMoney(calc.payment());
+            d->ui->m_paymentAmount->setValue(val.abs());
+            // reset payment as it might have changed due to rounding
+            val = d->ui->m_paymentAmount->value().abs();
+            if (moneyLend)
+                val = -val;
+            calc.setPmt(val.toDouble());
 
-          result = i18n("KMyMoney has calculated a periodic payment of %1 to cover principal and interest.", d->ui->m_paymentAmount->text());
+            result = i18n("KMyMoney has calculated a periodic payment of %1 to cover principal and interest.", d->ui->m_paymentAmount->text());
 
-          val = MyMoneyMoney(calc.futureValue());
-          if ((moneyBorrowed && val < MyMoneyMoney() && qAbs(val.toDouble()) >= qAbs(calc.payment()))
-              || (moneyLend && val > MyMoneyMoney() && qAbs(val.toDouble()) >= qAbs(calc.payment()))) {
-              calc.setNpp(calc.npp() - 1);
-              // updateTermWidgets(calc.npp());
-              val = MyMoneyMoney(calc.futureValue());
-              MyMoneyMoney refVal(val);
-              d->ui->m_balloonAmount->setValue(refVal);
-              result += QString(" ");
-              result += i18n("The number of payments has been decremented and the balloon payment has been modified to %1.", d->ui->m_balloonAmount->text());
+            val = MyMoneyMoney(calc.futureValue());
+            if ((moneyBorrowed && val < MyMoneyMoney() && qAbs(val.toDouble()) >= qAbs(calc.payment()))
+                    || (moneyLend && val > MyMoneyMoney() && qAbs(val.toDouble()) >= qAbs(calc.payment()))) {
+                calc.setNpp(calc.npp() - 1);
+                // updateTermWidgets(calc.npp());
+                val = MyMoneyMoney(calc.futureValue());
+                MyMoneyMoney refVal(val);
+                d->ui->m_balloonAmount->setValue(refVal);
+                result += QString(" ");
+                result += i18n("The number of payments has been decremented and the balloon payment has been modified to %1.", d->ui->m_balloonAmount->text());
             } else if ((moneyBorrowed && val < MyMoneyMoney() && qAbs(val.toDouble()) < qAbs(calc.payment()))
                        || (moneyLend && val > MyMoneyMoney() && qAbs(val.toDouble()) < qAbs(calc.payment()))) {
-              d->ui->m_balloonAmount->setValue(MyMoneyMoney());
+                d->ui->m_balloonAmount->setValue(MyMoneyMoney());
             } else {
-              MyMoneyMoney refVal(val);
-              d->ui->m_balloonAmount->setValue(refVal);
-              result += i18n("The balloon payment has been modified to %1.", d->ui->m_balloonAmount->text());
+                MyMoneyMoney refVal(val);
+                d->ui->m_balloonAmount->setValue(refVal);
+                result += i18n("The balloon payment has been modified to %1.", d->ui->m_balloonAmount->text());
             }
 
         } else if (d->ui->m_termAmount->value() == 0) {
-          // calculate the number of payments out of the other information
-          val = MyMoneyMoney(calc.numPayments());
-          if (val == 0)
-            throw MYMONEYEXCEPTION_CSTRING("incorrect financial calculation");
+            // calculate the number of payments out of the other information
+            val = MyMoneyMoney(calc.numPayments());
+            if (val == 0)
+                throw MYMONEYEXCEPTION_CSTRING("incorrect financial calculation");
 
-          // if the number of payments has a fractional part, then we
-          // round it to the smallest integer and calculate the balloon payment
-          result = i18n("KMyMoney has calculated the term of your loan as %1. ", updateTermWidgets(qFloor(val.toDouble())));
+            // if the number of payments has a fractional part, then we
+            // round it to the smallest integer and calculate the balloon payment
+            result = i18n("KMyMoney has calculated the term of your loan as %1. ", updateTermWidgets(qFloor(val.toDouble())));
 
-          if (val.toDouble() != qFloor(val.toDouble())) {
-              calc.setNpp(qFloor(val.toDouble()));
-              val = MyMoneyMoney(calc.futureValue());
-              d->ui->m_balloonAmount->setValue(val);
-              result += i18n("The balloon payment has been modified to %1.", d->ui->m_balloonAmount->text());
+            if (val.toDouble() != qFloor(val.toDouble())) {
+                calc.setNpp(qFloor(val.toDouble()));
+                val = MyMoneyMoney(calc.futureValue());
+                d->ui->m_balloonAmount->setValue(val);
+                result += i18n("The balloon payment has been modified to %1.", d->ui->m_balloonAmount->text());
             }
 
         } else {
-          // calculate the future value of the loan out of the other information
-          val = MyMoneyMoney(calc.futureValue());
+            // calculate the future value of the loan out of the other information
+            val = MyMoneyMoney(calc.futureValue());
 
-          // we differentiate between the following cases:
-          // a) the future value is greater than a payment
-          // b) the future value is less than a payment or the loan is overpaid
-          // c) all other cases
-          //
-          // a) means, we have paid more than we owed. This can't be
-          // b) means, we paid more than we owed but the last payment is
-          //    less in value than regular payments. That means, that the
-          //    future value is to be treated as  (fully payed back)
-          // c) the loan is not payed back yet
-          if ((moneyBorrowed && val < MyMoneyMoney() && qAbs(val.toDouble()) > qAbs(calc.payment()))
-              || (moneyLend && val > MyMoneyMoney() && qAbs(val.toDouble()) > qAbs(calc.payment()))) {
-              // case a)
-              qDebug("Future Value is %f", val.toDouble());
-              throw MYMONEYEXCEPTION_CSTRING("incorrect financial calculation");
+            // we differentiate between the following cases:
+            // a) the future value is greater than a payment
+            // b) the future value is less than a payment or the loan is overpaid
+            // c) all other cases
+            //
+            // a) means, we have paid more than we owed. This can't be
+            // b) means, we paid more than we owed but the last payment is
+            //    less in value than regular payments. That means, that the
+            //    future value is to be treated as  (fully payed back)
+            // c) the loan is not payed back yet
+            if ((moneyBorrowed && val < MyMoneyMoney() && qAbs(val.toDouble()) > qAbs(calc.payment()))
+                    || (moneyLend && val > MyMoneyMoney() && qAbs(val.toDouble()) > qAbs(calc.payment()))) {
+                // case a)
+                qDebug("Future Value is %f", val.toDouble());
+                throw MYMONEYEXCEPTION_CSTRING("incorrect financial calculation");
 
             } else if ((moneyBorrowed && val < MyMoneyMoney() && qAbs(val.toDouble()) <= qAbs(calc.payment()))
                        || (moneyLend && val > MyMoneyMoney() && qAbs(val.toDouble()) <= qAbs(calc.payment()))) {
-              // case b)
-              val = 0;
+                // case b)
+                val = 0;
             }
 
-          result = i18n("KMyMoney has calculated a balloon payment of %1 for this loan.", val.abs().formatMoney(QString(), d->m_wizard->d_func()->precision()));
+            result = i18n("KMyMoney has calculated a balloon payment of %1 for this loan.", val.abs().formatMoney(QString(), d->m_wizard->d_func()->precision()));
 
-          if (!d->ui->m_balloonAmount->text().isEmpty()) {
-              if ((d->ui->m_balloonAmount->value().abs() - val.abs()).abs().toDouble() > 1) {
-                  throw MYMONEYEXCEPTION_CSTRING("incorrect financial calculation");
+            if (!d->ui->m_balloonAmount->text().isEmpty()) {
+                if ((d->ui->m_balloonAmount->value().abs() - val.abs()).abs().toDouble() > 1) {
+                    throw MYMONEYEXCEPTION_CSTRING("incorrect financial calculation");
                 }
-              result = i18n("KMyMoney has successfully verified your loan information.");
+                result = i18n("KMyMoney has successfully verified your loan information.");
             }
-          d->ui->m_balloonAmount->setValue(val);
+            d->ui->m_balloonAmount->setValue(val);
         }
 
     } catch (const MyMoneyException &) {
-      KMessageBox::error(0,
-                         i18n("You have entered mis-matching information. Please modify "
-                              "your figures or leave one value empty "
-                              "to let KMyMoney calculate it for you"),
-                         i18n("Calculation error"));
-      return;
+        KMessageBox::error(0,
+                           i18n("You have entered mis-matching information. Please modify "
+                                "your figures or leave one value empty "
+                                "to let KMyMoney calculate it for you"),
+                           i18n("Calculation error"));
+        return;
     }
 
     result += i18n("\n\nAccept this or modify the loan information and recalculate.");
@@ -300,21 +288,21 @@ namespace NewAccountWizard
 
     // now update change
     d->m_wizard->completeStateChanged();
-  }
+}
 
-  int LoanDetailsPage::term() const
-  {
+int LoanDetailsPage::term() const
+{
     Q_D(const LoanDetailsPage);
     int factor = 0;
 
     if (d->ui->m_termAmount->value() != 0) {
         factor = 1;
         switch (d->ui->m_termUnit->currentItem()) {
-          case Schedule::Occurrence::Yearly: // years
+        case Schedule::Occurrence::Yearly: // years
             factor = 12;
-            // intentional fall through
+        // intentional fall through
 
-          case Schedule::Occurrence::Monthly: // months
+        case Schedule::Occurrence::Monthly: // months
             factor *= 30;
             factor *= d->ui->m_termAmount->value();
             // factor now is the duration in days. we divide this by the
@@ -322,20 +310,20 @@ namespace NewAccountWizard
             factor /= d->m_wizard->d_func()->m_generalLoanInfoPage->d_func()->ui->m_paymentFrequency->daysBetweenEvents();
             break;
 
-          default:
+        default:
             qDebug("Unknown term unit %d in LoanDetailsPage::term(). Using payments.", (int)d->ui->m_termUnit->currentItem());
-            // intentional fall through
+        // intentional fall through
 
-          case Schedule::Occurrence::Once: // payments
+        case Schedule::Occurrence::Once: // payments
             factor = d->ui->m_termAmount->value();
             break;
-          }
-      }
+        }
+    }
     return factor;
-  }
+}
 
-  QString LoanDetailsPage::updateTermWidgets(const double val)
-  {
+QString LoanDetailsPage::updateTermWidgets(const double val)
+{
     Q_D(LoanDetailsPage);
     long vl = qFloor(val);
 
@@ -343,31 +331,31 @@ namespace NewAccountWizard
     Schedule::Occurrence unit = d->ui->m_termUnit->currentItem();
 
     if ((unit == Schedule::Occurrence::Monthly)
-        && ((vl % 12) == 0)) {
+            && ((vl % 12) == 0)) {
         vl /= 12;
         unit = Schedule::Occurrence::Yearly;
-      }
+    }
 
     switch (unit) {
-      case Schedule::Occurrence::Monthly:
+    case Schedule::Occurrence::Monthly:
         valString = i18np("one month", "%1 months", vl);
         d->ui->m_termUnit->setCurrentItem((int)Schedule::Occurrence::Monthly);
         break;
-      case Schedule::Occurrence::Yearly:
+    case Schedule::Occurrence::Yearly:
         valString = i18np("one year", "%1 years", vl);
         d->ui->m_termUnit->setCurrentItem((int)Schedule::Occurrence::Yearly);
         break;
-      default:
+    default:
         valString = i18np("one payment", "%1 payments", vl);
         d->ui->m_termUnit->setCurrentItem((int)Schedule::Occurrence::Once);
         break;
-      }
+    }
     d->ui->m_termAmount->setValue(vl);
     return valString;
-  }
+}
 
-  bool LoanDetailsPage::isComplete() const
-  {
+bool LoanDetailsPage::isComplete() const
+{
     Q_D(const LoanDetailsPage);
     // bool rc = KMyMoneyWizardPage::isComplete();
 
@@ -375,23 +363,23 @@ namespace NewAccountWizard
 
     if (d->ui->m_loanAmount->text().length() > 0) {
         fieldCnt++;
-      }
+    }
 
     if (d->ui->m_interestRate->text().length() > 0) {
         fieldCnt++;
-      }
+    }
 
     if (d->ui->m_termAmount->value() != 0) {
         fieldCnt++;
-      }
+    }
 
     if (d->ui->m_paymentAmount->text().length() > 0) {
         fieldCnt++;
-      }
+    }
 
     if (d->ui->m_balloonAmount->text().length() > 0) {
         fieldCnt++;
-      }
+    }
 
     d->ui->m_calculateButton->setEnabled(fieldCnt == 4 || (fieldCnt == 5 && d->m_needCalculate));
 
@@ -401,26 +389,26 @@ namespace NewAccountWizard
         d->m_wizard->d_func()->m_nextButton->setToolTip(i18n("Press Calculate to verify the values"));
         d->ui->m_calculateButton->setAutoDefault(true);
         d->ui->m_calculateButton->setDefault(true);
-      } else if (fieldCnt != 5) {
+    } else if (fieldCnt != 5) {
         d->m_wizard->d_func()->m_nextButton->setToolTip(i18n("Not all details supplied"));
         d->ui->m_calculateButton->setAutoDefault(true);
         d->ui->m_calculateButton->setDefault(true);
-      }
+    }
     d->m_wizard->d_func()->m_nextButton->setAutoDefault(!d->ui->m_calculateButton->autoDefault());
     d->m_wizard->d_func()->m_nextButton->setDefault(!d->ui->m_calculateButton->autoDefault());
 
     return (fieldCnt == 5) && !d->m_needCalculate;
-  }
+}
 
-  QWidget* LoanDetailsPage::initialFocusWidget() const
-  {
+QWidget* LoanDetailsPage::initialFocusWidget() const
+{
     Q_D(const LoanDetailsPage);
     return d->ui->m_paymentDue;
-  }
+}
 
-  KMyMoneyWizardPage* LoanDetailsPage::nextPage() const
-  {
+KMyMoneyWizardPage* LoanDetailsPage::nextPage() const
+{
     Q_D(const LoanDetailsPage);
     return d->m_wizard->d_func()->m_loanPaymentPage;
-  }
+}
 }
